==> falkon_24.01.75.orig.tar.xz: falkon-24.01.75/src/lib/adblock/adblockmatcher.h <==
/* ============================================================
* Falkon - Qt web browser
* Copyright (C) 2014-2017 David Rosca <nowrep@gmail.com>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
* ============================================================ */
#ifndef ADBLOCKMATCHER_H
#define ADBLOCKMATCHER_H

#include <QUrl>
#include <QObject>

#include "qzcommon.h"
#include "adblocksearchtree.h"

class QWebEngineUrlRequestInfo;

class AdBlockManager;

class FALKON_EXPORT AdBlockMatcher : public QObject
{
    Q_OBJECT

public:
    explicit AdBlockMatcher(AdBlockManager* manager);
    ~AdBlockMatcher();

    const AdBlockRule* match(const QWebEngineUrlRequestInfo &request, const QString &urlDomain, const QString &urlString) const;

    bool adBlockDisabledForUrl(const QUrl &url) const;
    bool elemHideDisabledForUrl(const QUrl &url) const;
    bool genericElemHideDisabledForUrl(const QUrl &url) const;

    QString elementHidingRules() const;
    QString elementHidingRulesForDomain(const QString &domain) const;

public Q_SLOTS:
    void update();
    void clear();

private:
    AdBlockManager* m_manager;

    QVector<AdBlockRule*> m_createdRules;
    QVector<const AdBlockRule*> m_networkExceptionRules;
    QVector<const AdBlockRule*> m_networkBlockRules;
    QVector<const AdBlockRule*> m_domainRestrictedCssRules;
    QVector<const AdBlockRule*> m_documentRules;
    QVector<const AdBlockRule*> m_elemhideRules;
    QVector<const AdBlockRule*> m_generichideRules;

    QString m_elementHidingRules;
    AdBlockSearchTree m_networkBlockTree;
    AdBlockSearchTree m_networkExceptionTree;
};

#endif // ADBLOCKMATCHER_H

==> falkon_25.08.1.orig.tar.xz: falkon-25.08.1/src/lib/adblock/adblockmatcher.h <==
/* ============================================================
* Falkon - Qt web browser
* Copyright (C) 2014-2017 David Rosca <nowrep@gmail.com>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
* ============================================================ */
#ifndef ADBLOCKMATCHER_H
#define ADBLOCKMATCHER_H

#include <QUrl>
#include <QObject>

#include "qzcommon.h"
#include "adblocksearchtree.h"

class QWebEngineUrlRequestInfo;

class AdBlockManager;

class FALKON_EXPORT AdBlockMatcher : public QObject
{
    Q_OBJECT

public:
    explicit AdBlockMatcher(AdBlockManager* manager);
    ~AdBlockMatcher();

    const AdBlockRule* match(const QWebEngineUrlRequestInfo &request, const QString &urlDomain, const QString &urlString) const;

    bool adBlockDisabledForUrl(const QUrl &url) const;
    bool elemHideDisabledForUrl(const QUrl &url) const;
    bool genericElemHideDisabledForUrl(const QUrl &url) const;

    QString elementHidingRules() const;
    QString elementHidingRulesForDomain(const QString &domain) const;

    QString elementRemoveRulesForDomain(const QString &domain) const;

public Q_SLOTS:
    void update();
    void clear();

private:
    AdBlockManager* m_manager;

    QVector<AdBlockRule*> m_createdRules;
    QVector<const AdBlockRule*> m_networkExceptionRules;
    QVector<const AdBlockRule*> m_networkBlockRules;
    QVector<const AdBlockRule*> m_domainRestrictedCssRules;
    QVector<const AdBlockRule*> m_documentRules;
    QVector<const AdBlockRule*> m_elemhideRules;
    QVector<const AdBlockRule*> m_elementRemoveRules;
    QVector<const AdBlockRule*> m_generichideRules;

    QString m_elementHidingRules;
    AdBlockSearchTree m_networkBlockTree;
    AdBlockSearchTree m_networkExceptionTree;
};

#endif // ADBLOCKMATCHER_H
